==> ViennaRNA-2.4.2.tar.gz: ViennaRNA-2.4.2/doc/html/group__fold__compound_structvrna__fc__s.js <==
var group__fold__compound_structvrna__fc__s =
[
    [ "type", "group__fold__compound.html#ac5eab693deac9a1a40c2a95ac294707c", null ],
    [ "length", "group__fold__compound.html#a95fbfed770b858e50c766505dc4bf998", null ],
    [ "cutpoint", "group__fold__compound.html#ae1a7bbff0256577e2b22709bac11fdb4", null ],
    [ "strand_number", "group__fold__compound.html#a23304c5186dfae97bc69dc19d37f70c3", null ],
    [ "hc", "group__fold__compound.html#aceaa904dbf50092d403ca99422e8f824", null ],
    [ "matrices", "group__fold__compound.html#aca8be7bdc65bafe2172c6ee777f18568", null ],
    [ "exp_matrices", "group__fold__compound.html#afc38ed5a1028a2712d2365274bf49727", null ],
    [ "params", "group__fold__compound.html#a19b8720c2c5321c1b97c830bd17566ea", null ],
    [ "exp_params", "group__fold__compound.html#a7052a5d24f6091b9c5f79edcc9456a12", null ],
    [ "iindx", "group__fold__compound.html#afdead4cf55c882d3497e779573e17e03", null ],
    [ "jindx", "group__fold__compound.html#a5037235dee512efd85ca543780bbca1a", null ],
    [ "stat_cb", "group__fold__compound.html#a87a83f6795b569000efcbe65acc3dd81", null ],
    [ "auxdata", "group__fold__compound.html#a20048e0c369e9f24b55423d600037c68", null ],
    [ "free_auxdata", "group__fold__compound.html#a8e84dbabab016ecd74da6c38cb94e816", null ],
    [ "domains_struc", "group__fold__compound.html#ac25a84f2658de0d7a54cd710c16198b1", null ],
    [ "domains_up", "group__fold__compound.html#a4f70b6d32681fc8ca061236f21819ae7", null ],
    [ "sequence", "group__fold__compound.html#a87f6abcda89cfb7a486c97e1f5371525", null ],
    [ "sequence_encoding", "group__fold__compound.html#a9934bdb695d35a3544285cbcc19f9763", null ],
    [ "ptype", "group__fold__compound.html#a3fbea559f1d1976b2d67c215cdeee0b2", null ],
    [ "ptype_pf_compat", "group__fold__compound.html#a7fe1235ce3d41287695f1ae1e283e8fc", null ],
    [ "sc", "group__fold__compound.html#ac7089e90460ad3990a308808c8044c9f", null ],
    [ "sequences", "group__fold__compound.html#a965dbb42f2e13cace5aa3bbab4396530", null ],
    [ "n_seq", "group__fold__compound.html#a614702ab74478e786272be44f8cebfe3", null ],
    [ "cons_seq", "group__fold__compound.html#ac472afde64d8b3c8b84e4809fda7d814", null ],
    [ "S_cons", "group__fold__compound.html#aa3fab7ae38ebfed2028375221d295686", null ],
    [ "S", "group__fold__compound.html#aebb37297f92c7bd22aac6343f8f61d61", null ],
    [ "S5", "group__fold__compound.html#a78d089b475e2230bd536b9a6ed8bb17c", null ],
    [ "S3", "group__fold__compound.html#af6ab2a25b84d2308ee23f6b11b5fd52d", null ],
    [ "pscore", "group__fold__compound.html#a14dc7755af6019ddbd0cf94b209e89dd", null ],
    [ "pscore_local", "group__fold__compound.html#ad966c15907e6c2e32b0910c7a3154509", null ],
    [ "pscore_pf_compat", "group__fold__compound.html#abf5e82d14649b6179ae60ed7da6e4fc0", null ],
    [ "scs", "group__fold__compound.html#ac2b047fddabc51a76a96511174e47db1", null ],
    [ "maxD1", "group__fold__compound.html#a426305721b16023f2f3247f7354d2c46", null ],
    [ "maxD2", "group__fold__compound.html#a38695774fd396c892f9a70d39978b231", null ],
    [ "reference_pt1", "group__fold__compound.html#aa279ba4bd0ff541d435d3a049687f3ac", null ],
    [ "reference_pt2", "group__fold__compound.html#a926ad253f5f0eed642bc227493d0278d", null ],
    [ "referenceBPs1", "group__fold__compound.html#a62a8d4ab8dadffbf09da917adff6c71e", null ],
    [ "referenceBPs2", "group__fold__compound.html#a19187f33433e84683730dedff8544f71", null ],
    [ "bpdist", "group__fold__compound.html#a5c53e55583ce096148075bc240fc2bce", null ],
    [ "mm1", "group__fold__compound.html#a0af5a888bac2ae32107da32776144504", null ],
    [ "mm2", "group__fold__compound.html#a54c0b979274b285a7e093ed54aa3252e", null ],
    [ "window_size", "group__fold__compound.html#adacbf7cdfb47d3072683ab509de735f6", null ],
    [ "ptype_local", "group__fold__compound.html#a2ecb8ff5e21190936a8a146be7a251ff", null ]
];

==> ViennaRNA-2.4.15.tar.gz: ViennaRNA-2.4.15/doc/html/group__fold__compound_structvrna__fc__s.js <==
var group__fold__compound_structvrna__fc__s =
[
    [ "type", "group__fold__compound.html#a391bcf8ac5997784aaf780cdd251c464", null ],
    [ "length", "group__fold__compound.html#a95fbfed770b858e50c766505dc4bf998", null ],
    [ "cutpoint", "group__fold__compound.html#ae1a7bbff0256577e2b22709bac11fdb4", null ],
    [ "strand_number", "group__fold__compound.html#a23304c5186dfae97bc69dc19d37f70c3", null ],
    [ "strand_order", "group__fold__compound.html#a3bf15e0e44539f9f622fd09227bf3de1", null ],
    [ "strand_start", "group__fold__compound.html#a571ee9a932f633c7d9167ae029573935", null ],
    [ "strand_end", "group__fold__compound.html#aaa1b51bc6eb47cc661fea834d7175a54", null ],
    [ "hc", "group__fold__compound.html#aceaa904dbf50092d403ca99422e8f824", null ],
    [ "matrices", "group__fold__compound.html#aca8be7bdc65bafe2172c6ee777f18568", null ],
    [ "exp_matrices", "group__fold__compound.html#afc38ed5a1028a2712d2365274bf49727", null ],
    [ "params", "group__fold__compound.html#a19b8720c2c5321c1b97c830bd17566ea", null ],
    [ "exp_params", "group__fold__compound.html#a7052a5d24f6091b9c5f79edcc9456a12", null ],
    [ "iindx", "group__fold__compound.html#afdead4cf55c882d3497e779573e17e03", null ],
    [ "jindx", "group__fold__compound.html#a5037235dee512efd85ca543780bbca1a", null ],
    [ "stat_cb", "group__fold__compound.html#a87a83f6795b569000efcbe65acc3dd81", null ],
    [ "auxdata", "group__fold__compound.html#a20048e0c369e9f24b55423d600037c68", null ],
    [ "free_auxdata", "group__fold__compound.html#a8e84dbabab016ecd74da6c38cb94e816", null ],
    [ "domains_struc", "group__fold__compound.html#ac25a84f2658de0d7a54cd710c16198b1", null ],
    [ "domains_up", "group__fold__compound.html#a4f70b6d32681fc8ca061236f21819ae7", null ],
    [ "sequence", "group__fold__compound.html#a87f6abcda89cfb7a486c97e1f5371525", null ],
    [ "sequence_encoding", "group__fold__compound.html#a9934bdb695d35a3544285cbcc19f9763", null ],
    [ "ptype", "group__fold__compound.html#a3fbea559f1d1976b2d67c215cdeee0b2", null ],
    [ "ptype_pf_compat", "group__fold__compound.html#a7fe1235ce3d41287695f1ae1e283e8fc", null ],
    [ "sc", "group__fold__compound.html#ac7089e90460ad3990a308808c8044c9f", null ],
    [ "sequences", "group__fold__compound.html#a965dbb42f2e13cace5aa3bbab4396530", null ],
    [ "n_seq", "group__fold__compound.html#a614702ab74478e786272be44f8cebfe3", null ],
    [ "cons_seq", "group__fold__compound.html#ac472afde64d8b3c8b84e4809fda7d814", null ],
    [ "S_cons", "group__fold__compound.html#aa3fab7ae38ebfed2028375221d295686", null ],
    [ "S", "group__fold__compound.html#aebb37297f92c7bd22aac6343f8f61d61", null ],
    [ "S5", "group__fold__compound.html#a78d089b475e2230bd536b9a6ed8bb17c", null ],
    [ "S3", "group__fold__compound.html#af6ab2a25b84d2308ee23f6b11b5fd52d", null ],
    [ "pscore", "group__fold__compound.html#a14dc7755af6019ddbd0cf94b209e89dd", null ],
    [ "pscore_local", "group__fold__compound.html#ad966c15907e6c2e32b0910c7a3154509", null ],
    [ "pscore_pf_compat", "group__fold__compound.html#abf5e82d14649b6179ae60ed7da6e4fc0", null ],
    [ "scs", "group__fold__compound.html#ac2b047fddabc51a76a96511174e47db1", null ],
    [ "maxD1", "group__fold__compound.html#a426305721b16023f2f3247f7354d2c46", null ],
    [ "maxD2", "group__fold__compound.html#a38695774fd396c892f9a70d39978b231", null ],
    [ "reference_pt1", "group__fold__compound.html#aa279ba4bd0ff541d435d3a049687f3ac", null ],
    [ "reference_pt2", "group__fold__compound.html#a926ad253f5f0eed642bc227493d0278d", null ],
    [ "referenceBPs1", "group__fold__compound.html#a62a8d4ab8dadffbf09da917adff6c71e", null ],
    [ "referenceBPs2", "group__fold__compound.html#a19187f33433e84683730dedff8544f71", null ],
    [ "bpdist", "group__fold__compound.html#a5c53e55583ce096148075bc240fc2bce", null ],
    [ "mm1", "group__fold__compound.html#a0af5a888bac2ae32107da32776144504", null ],
    [ "mm2", "group__fold__compound.html#a54c0b979274b285a7e093ed54aa3252e", null ],
    [ "window_size", "group__fold__compound.html#adacbf7cdfb47d3072683ab509de735f6", null ],
    [ "ptype_local", "group__fold__compound.html#a2ecb8ff5e21190936a8a146be7a251ff", null ]
];
